import { FC, ReactNode } from 'react';
interface UsercentricsProviderProps {
    children: ReactNode;
    /**
     * Whether to throw if invalid Service Id has been used.
     * @default false
     */
    strictMode?: boolean;
    /**
     * The timeout value in milliseconds after which loading of the Usercentrics
     * script will be assumed to have failed.
     * @default 5000
     */
    timeout?: number;
    /**
     * The configured window event name from Usercentrics admin interface.
     * @see https://docs.usercentrics.com/#/v2-events?id=usage-as-window-event
     */
    windowEventName: string;
}
/**
 * The provider component for listening to events from the Usercentrics Browser API.
 * Render this once and wrap your application in it.
 *
 * @example <caption>Basic usage</caption>
 * () => <UsercentricsProvider windowEventName="ucEvent"><App /></UsercentricsProvider>
 *
 * @example <caption>Custom timeout in milliseconds</caption>
 * () => <UsercentricsProvider timeout={100} windowEventName="ucEvent"><App /></UsercentricsProvider>
 */
export declare const UsercentricsProvider: FC<UsercentricsProviderProps>;
export {};
